Coverage for girder/api/v1/docs/file_docs: 100%

# Coverage for girder/api/v1/docs/file_docs : 100%

## 8 statements 8 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 | #!/usr/bin/env python # -*- coding: utf-8 -*- ############################################################################### # Copyright 2013 Kitware Inc. # # Licensed under the Apache License, Version 2.0 ( the "License" ); # you may not use this file except in compliance with the License. # You may obtain a copy of the License at # # http://www.apache.org/licenses/LICENSE-2.0 # # Unless required by applicable law or agreed to in writing, software # distributed under the License is distributed on an "AS IS" BASIS, # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. # See the License for the specific language governing permissions and # limitations under the License. ############################################################################### from ..api_docs import Describe apis = [] apis.append({ 'path': '/file', 'resource': 'file', 'operations': [{ 'httpMethod': 'POST', 'nickname': 'initUpload', 'responseClass': 'Upload', 'summary': 'Start a new upload.', 'parameters': [ Describe.param( 'parentType', "Type being uploaded into, either 'folder' or " "'item'."), Describe.param('parentId', "The ID of the parent."), Describe.param('name', "Name of the file being uploaded."), Describe.param('size', "Size in bytes of the file.", dataType='integer'), Describe.param('mimeType', "The MIME type of the file.", required=False) ], 'errorResponses': [ Describe.errorResponse(), Describe.errorResponse('Write access was denied on the parent', 403) ] }] }) apis.append({ 'path': '/file/{fileId}', 'resource': 'file', 'operations': [{ 'httpMethod': 'GET', 'nickname': 'getFileById', 'responseClass': 'File', 'summary': 'Get a file by ID.', 'parameters': [ Describe.param( 'fileId', 'The ID of the file.', paramType='path') ], 'errorResponses': [ Describe.errorResponse('ID was invalid.'), Describe.errorResponse( 'Read access was denied for the containing folder.', 403) ] }, { 'httpMethod': 'DELETE', 'nickname': 'deleteFileById', 'summary': 'Delete a file by ID.', 'parameters': [ Describe.param( 'fileId', 'The ID of the file.', paramType='path') ], 'errorResponses': [ Describe.errorResponse('ID was invalid.'), Describe.errorResponse( 'Admin access was denied for the containing folder.', 403) ] }] }) apis.append({ 'path': '/file/{fileId}/download', 'resource': 'file', 'operations': [{ 'httpMethod': 'GET', 'nickname': 'downloadFile', 'summary': 'Download a file.', 'parameters': [ Describe.param( 'fileId', 'The ID of the file.', paramType='path') ], 'errorResponses': [ Describe.errorResponse('ID was invalid.'), Describe.errorResponse( 'Read access was denied for the containing folder.', 403) ] }] }) apis.append({ 'path': '/file/chunk', 'resource': 'file', 'operations': [{ 'httpMethod': 'POST', 'nickname': 'uploadChunk', 'summary': 'Upload a chunk of a file with multipart/form-data.', 'parameters': [ Describe.param('uploadId', 'The ID of the upload record.'), Describe.param('offset', 'Offset of the chunk in the file.', dataType='integer'), Describe.param('chunk', 'The actual bytes of the chunk.', dataType='byte') ], 'errorResponses': [ Describe.errorResponse('ID was invalid.'), Describe.errorResponse( 'You are not the same user who initiated the upload.', 403) ] }] }) apis.append({ 'path': '/file/offset', 'resource': 'file', 'operations': [{ 'httpMethod': 'GET', 'nickname': 'uploadChunk', 'summary': 'Request required offset before resuming an upload.', 'parameters': [ Describe.param('uploadId', 'The ID of the upload record.') ], 'errorResponses': [ Describe.errorResponse('ID was invalid, or the offset did not match' ' the server record.') ] }] }) Describe.declareApi('file', apis=apis)